==> Cenon-3.9.3.tar.bz2: Cenon/EPSExport.h <==
/* EPSExport.h
 * EPSExport object
 *
 * Copyright (C) 2000-2002 by vhf interservice GmbH
 * Author:   Ilonka Fleischmann
 *
 * created:  1996-03-13
 * modified: 2002-07-15
 *
 * This file is part of the vhf Export Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the vhf Public License as
 * published by the vhf interservice GmbH. Among other things,
 * the License requires that the copyright notices and this notice
 * be preserved on all copies.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the vhf Public License for more details.
 *
 * You should have received a copy of the vhf Public License along
 * with this library; see the file LICENSE. If not, write to vhf.
 *
 * If you want to link this library to your proprietary software,
 * or for other uses which are not covered by the definitions
 * laid down in the vhf Public License, vhf also offers a proprietary
 * license scheme. See the vhf internet pages or ask for details.
 *
 * vhf interservice GmbH, Im Marxle 3, 72119 Altingen, Germany
 * eMail: info@vhf.de
 * http://www.vhf.de
 */

#ifndef VHF_H_EPSEXPORT
#define VHF_H_EPSEXPORT

@interface EPSExport:NSObject
{
    id	docView;	// the Document
}

/* class methods */
+ (EPSExport*)epsExport;

- (void)setDocumentView:view;
- (BOOL)writeToFile:(NSString*)filename;

@end

#endif // VHF_H_EPSEXPORT

==> Cenon-4.0.3.tar.bz2: Cenon/EPSExport.h <==
/* EPSExport.h
 * EPSExport object
 *
 * Copyright (C) 2000-2014 by Cenon GmbH
 * Author:   Ilonka Fleischmann
 *
 * created:  1996-03-13
 * modified: 2002-07-15
 *
 * This file is part of the vhf Export Library.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the Cenon Public License as
 * published by the Cenon GmbH. Among other things,
 * the License requires that the copyright notices and this notice
 * be preserved on all copies.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the Cenon Public License for more details.
 *
 * You should have received a copy of the Cenon Public License along
 * with this library; see the file LICENSE. If not, write to Cenon.
 *
 * If you want to link this library to your proprietary software,
 * or for other uses which are not covered by the definitions
 * laid down in the Cenon Public License, vhf also offers a proprietary
 * license scheme. See the vhf internet pages or ask for details.
 *
 * Cenon GmbH, Schwabstr. 45, 72108 Rottenburg a.N., Germany
 * eMail: info@Cenon.com
 * http://www.Cenon.de
 */

#ifndef CEN_H_EPSEXPORT
#define CEN_H_EPSEXPORT

@interface EPSExport:NSObject
{
    id	docView;	// the Document
}

/* class methods */
+ (EPSExport*)epsExport;

- (void)setDocumentView:view;
- (BOOL)writeToFile:(NSString*)filename;

@end

#endif // CEN_H_EPSEXPORT
